package javax.management.openmbean;

import java.util.HashSet;
import java.util.Arrays;
import java.util.Objects;
import javax.management.MBeanOperationInfo;
import javax.management.MBeanConstructorInfo;
import javax.management.MBeanAttributeInfo;
import javax.management.Descriptor;
import javax.management.MBeanNotificationInfo;
import javax.management.MBeanInfo;

public class OpenMBeanInfoSupport extends MBeanInfo implements OpenMBeanInfo
{
    static final long serialVersionUID = 4349395935420511492L;
    private transient Integer myHashCode;
    private transient String myToString;
    
    public OpenMBeanInfoSupport(String s, String s2, OpenMBeanAttributeInfo[] array, OpenMBeanConstructorInfo[] array2, OpenMBeanOperationInfo[] array3, MBeanNotificationInfo[] array4) {
        this(s, s2, array, array2, array3, array4, (Descriptor)null);
    }
    
    public OpenMBeanInfoSupport(String className, String description, OpenMBeanAttributeInfo[] array, OpenMBeanConstructorInfo[] array2, OpenMBeanOperationInfo[] array3, MBeanNotificationInfo[] array4, Descriptor descriptor) {
        super(className, description, attributeArray(array), constructorArray(array2), operationArray(array3), (array4 == null) ? null : ((MBeanNotificationInfo[])array4.clone()), descriptor);
        this.myHashCode = null;
        this.myToString = null;
    }
    
    private static MBeanAttributeInfo[] attributeArray(OpenMBeanAttributeInfo[] array) {
        if (array == null) {
            return null;
        }
        MBeanAttributeInfo[] array2 = new MBeanAttributeInfo[array.length];
        System.arraycopy(array, 0, array2, 0, array.length);
        return array2;
    }
    
    private static MBeanConstructorInfo[] constructorArray(OpenMBeanConstructorInfo[] array) {
        if (array == null) {
            return null;
        }
        MBeanConstructorInfo[] array2 = new MBeanConstructorInfo[array.length];
        System.arraycopy(array, 0, array2, 0, array.length);
        return array2;
    }
    
    private static MBeanOperationInfo[] operationArray(OpenMBeanOperationInfo[] array) {
        if (array == null) {
            return null;
        }
        MBeanOperationInfo[] array2 = new MBeanOperationInfo[array.length];
        System.arraycopy(array, 0, array2, 0, array.length);
        return array2;
    }
    
    @Override
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        OpenMBeanInfo openMBeanInfo;
        try {
            openMBeanInfo = (OpenMBeanInfo)o;
        }
        catch (ClassCastException ex) {
            return false;
        }
        return Objects.equals(this.getClassName(), openMBeanInfo.getClassName()) && sameArrayContents(this.getAttributes(), openMBeanInfo.getAttributes()) && sameArrayContents(this.getConstructors(), openMBeanInfo.getConstructors()) && sameArrayContents(this.getOperations(), openMBeanInfo.getOperations()) && sameArrayContents(this.getNotifications(), openMBeanInfo.getNotifications());
    }
    
    private static <T> boolean sameArrayContents(T[] a, T[] a2) {
        return new HashSet(Arrays.asList(a)).equals(new HashSet(Arrays.asList(a2)));
    }
    
    @Override
    public int hashCode() {
        if (this.myHashCode == null) {
            int n = 0;
            if (this.getClassName() != null) {
                n += this.getClassName().hashCode();
            }
            this.myHashCode = Integer.valueOf(n + arraySetHash(this.getAttributes()) + arraySetHash(this.getConstructors()) + arraySetHash(this.getOperations()) + arraySetHash(this.getNotifications()));
        }
        return (int)this.myHashCode;
    }
    
    private static <T> int arraySetHash(T[] a) {
        return new HashSet(Arrays.asList(a)).hashCode();
    }
    
    @Override
    public String toString() {
        if (this.myToString == null) {
            this.myToString = this.getClass().getName() + "(mbean_class_name=" + this.getClassName() + ",attributes=" + Arrays.asList(this.getAttributes()).toString() + ",constructors=" + Arrays.asList(this.getConstructors()).toString() + ",operations=" + Arrays.asList(this.getOperations()).toString() + ",notifications=" + Arrays.asList(this.getNotifications()).toString() + ",descriptor=" + this.getDescriptor() + ")";
        }
        return this.myToString;
    }
}
